## dbt-tests-adapter 1.18.0 - August 19, 2025

### Features

- Add new test for test unit tests involing models with columns with reserved words ([#1273](https://github.com/dbt-labs/dbt-adapters/issues/1273))
